==> jc-1.4.0.tar.gz: soot/coffi/OutFlow.h <==
// class soot.coffi.OutFlow

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b9dfb3b2a2f82a5a soot_coffi_OutFlow

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_OutFlow_H_
#define _JC_soot_coffi_OutFlow_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_TypeStack$object;

// Typedefs
typedef struct _jc_soot_coffi_OutFlow$sub_refs	_jc_soot_coffi_OutFlow$sub_refs;
typedef struct _jc_soot_coffi_OutFlow$sub_nonrefs	_jc_soot_coffi_OutFlow$sub_nonrefs;
typedef struct _jc_soot_coffi_OutFlow$refs	_jc_soot_coffi_OutFlow$refs;
typedef struct _jc_soot_coffi_OutFlow$nonrefs	_jc_soot_coffi_OutFlow$nonrefs;
typedef struct _jc_soot_coffi_OutFlow$object	_jc_soot_coffi_OutFlow$object;

typedef const struct _jc_soot_coffi_OutFlow$vmethods	_jc_soot_coffi_OutFlow$vmethods;
typedef const struct _jc_soot_coffi_OutFlow$vtable	_jc_soot_coffi_OutFlow$vtable;
typedef const struct _jc_soot_coffi_OutFlow$vtype	_jc_soot_coffi_OutFlow$vtype;

// Constructors
extern void _jc_soot_coffi_OutFlow$method$_init$c1d42c40306bdc14(_jc_env *, struct _jc_soot_coffi_OutFlow$object *, struct _jc_soot_coffi_TypeStack$object *);

// Virtual methods structure
struct _jc_soot_coffi_OutFlow$vmethods {
};

// Vtable
struct _jc_soot_coffi_OutFlow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_OutFlow$vmethods	soot_coffi_OutFlow;
};

// Vtype
struct _jc_soot_coffi_OutFlow$vtype {
	_jc_type			type;
	_jc_soot_coffi_OutFlow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_OutFlow$sub_refs {
	struct _jc_soot_coffi_TypeStack$object	*typeStack;
};

// Reference instance fields (object)
struct _jc_soot_coffi_OutFlow$refs {
    _jc_soot_coffi_OutFlow$sub_refs	soot_coffi_OutFlow;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_OutFlow$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_OutFlow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_OutFlow$sub_nonrefs	soot_coffi_OutFlow;
};

// Object instance structure
struct _jc_soot_coffi_OutFlow$object {
	_jc_soot_coffi_OutFlow$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_OutFlow$vtype	*vtype;
	_jc_soot_coffi_OutFlow$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_OutFlow$vtype _jc_soot_coffi_OutFlow$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_OutFlow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_OutFlow$class_object;

#endif	/* _JC_soot_coffi_OutFlow_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/OutFlow.h <==
// class soot.coffi.OutFlow

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b9dfb3b2a2f82a5a soot_coffi_OutFlow

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_OutFlow_H_
#define _JC_soot_coffi_OutFlow_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_TypeStack$object;

// Typedefs
typedef struct _jc_soot_coffi_OutFlow$sub_refs	_jc_soot_coffi_OutFlow$sub_refs;
typedef struct _jc_soot_coffi_OutFlow$sub_nonrefs	_jc_soot_coffi_OutFlow$sub_nonrefs;
typedef struct _jc_soot_coffi_OutFlow$refs	_jc_soot_coffi_OutFlow$refs;
typedef struct _jc_soot_coffi_OutFlow$nonrefs	_jc_soot_coffi_OutFlow$nonrefs;
typedef struct _jc_soot_coffi_OutFlow$object	_jc_soot_coffi_OutFlow$object;

typedef const struct _jc_soot_coffi_OutFlow$vmethods	_jc_soot_coffi_OutFlow$vmethods;
typedef const struct _jc_soot_coffi_OutFlow$vtable	_jc_soot_coffi_OutFlow$vtable;
typedef const struct _jc_soot_coffi_OutFlow$vtype	_jc_soot_coffi_OutFlow$vtype;

// Constructors
extern void _jc_soot_coffi_OutFlow$method$_init$c1d42c40306bdc14(_jc_env *, struct _jc_soot_coffi_OutFlow$object *, struct _jc_soot_coffi_TypeStack$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_OutFlow$vmethods {
};

// Vtable
struct _jc_soot_coffi_OutFlow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_OutFlow$vmethods	soot_coffi_OutFlow;
};

// Vtype
struct _jc_soot_coffi_OutFlow$vtype {
	_jc_type			type;
	_jc_soot_coffi_OutFlow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_OutFlow$sub_refs {
	struct _jc_soot_coffi_TypeStack$object	*typeStack;
};

// Reference instance fields (object)
struct _jc_soot_coffi_OutFlow$refs {
    _jc_soot_coffi_OutFlow$sub_refs	soot_coffi_OutFlow;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_OutFlow$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_OutFlow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_OutFlow$sub_nonrefs	soot_coffi_OutFlow;
};

// Object instance structure
struct _jc_soot_coffi_OutFlow$object {
	_jc_soot_coffi_OutFlow$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_OutFlow$vtype	*vtype;
	_jc_soot_coffi_OutFlow$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_OutFlow$vtype _jc_soot_coffi_OutFlow$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_OutFlow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_OutFlow$class_object;

#endif	/* _JC_soot_coffi_OutFlow_H_ */
